%define major	5
%define libname	%mklibname zmq %{major}
%define develname %mklibname zmq -d

Summary:	Software library for fast, message-based applications
Name:		zeromq
Version:	4.3.5
Release:	%mkrel 1
Url:		https://www.zeromq.org/
License:	LGPLv3+
Group:		Development/Other
Source0:	https://github.com/zeromq/libzmq/releases/download/v%{version}/zeromq-%{version}.tar.gz
Patch0:		zeromq-4.3.3-mga-link_pgm-5.3.patch

# Modified from FindSodium.cmake
Source2:	FindUnwind.cmake

BuildRequires:	asciidoc
BuildRequires:	cmake
BuildRequires:	pkgconfig(gnutls) >= 3.6.7
BuildRequires:	pkgconfig(libsodium)
BuildRequires:	pkgconfig(libunwind)
BuildRequires:	pkgconfig(openpgm-5.3)

%description
The 0MQ lightweight messaging kernel is a library which extends the
standard socket interfaces with features traditionally provided by
specialized messaging middle-ware products. 0MQ sockets provide an
abstraction of asynchronous message queues, multiple messaging
patterns, message filtering (subscriptions), seamless access to
multiple transport protocols and more.

%package -n	%{libname}
Summary:	Software library for fast, message-based applications
Group:		System/Libraries
Obsoletes:	%{_lib}zeromq5 < 4.3.3

%description -n %{libname}
The 0MQ lightweight messaging kernel is a library which extends the
standard socket interfaces with features traditionally provided by
specialized messaging middle-ware products. 0MQ sockets provide an
abstraction of asynchronous message queues, multiple messaging
patterns, message filtering (subscriptions), seamless access to
multiple transport protocols and more.

This package contains the %{name} shared library.

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Requires:	%{name}-utils = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{_lib}zeromq-devel < 4.3.3

%description -n %{develname}
The 0MQ lightweight messaging kernel is a library which extends the
standard socket interfaces with features traditionally provided by
specialized messaging middle-ware products. 0MQ sockets provide an
abstraction of asynchronous message queues, multiple messaging
patterns, message filtering (subscriptions), seamless access to
multiple transport protocols and more.

This package contains the libraries and header files needed to develop
applications that use %{name}.

%package utils
Summary:	Utility binaries for zeromq
Group:		Development/C

%description utils
Utility binaries for zeromq

%prep
%autosetup -p1

# find libunwind
install -pm644 %{SOURCE2} FindUnwind.cmake

# Fix lib path in .pc 
sed -i 's:@libdir@:%{_libdir}:' src/libzmq.pc.in

%build
%cmake \
	-DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{libname} \
	-DWITH_OPENPGM:BOOL=ON \
	-DWITH_LIBSODIUM:BOOL=ON \
	-DENABLE_DRAFTS:BOOL=ON \
	-DBUILD_STATIC:BOOL=OFF\
	-DZMQ_BUILD_TESTS=OFF
# Tests fail to build in 4.3.5
	
%cmake_build

# tests locally OK, fails in BS
%if 0
%check
%ctest
%endif

%install
%cmake_install

# Docs get installed in wrong places
mkdir -p %{buildroot}%{_docdir}/%{libname}
mv %{buildroot}%{_usr}/doc/zmq/* %{buildroot}%{_datadir}/doc/%{libname}/
mv %{buildroot}%{_datadir}/zmq/* %{buildroot}%{_datadir}/doc/%{libname}/

# we don't want these
find %{buildroot} -name "*.la" -delete

%files -n %{libname}
%{_libdir}/libzmq.so.%{major}{,.*}

%files -n %{develname}
%doc %{_docdir}/%{libname}/*
%{_libdir}/libzmq.so
%{_libdir}/pkgconfig/libzmq.pc
%{_includedir}/zmq*
%dir %{_libdir}/cmake/ZeroMQ
%{_libdir}/cmake/ZeroMQ/*.cmake

%files utils
%{_bindir}/inproc_lat
%{_bindir}/inproc_thr
%{_bindir}/local_lat
%{_bindir}/local_thr
%{_bindir}/remote_lat
%{_bindir}/remote_thr
%{_bindir}/proxy_thr


%changelog
* Mon Apr 08 2024 barjac <barjac> 4.3.5-1.mga10
+ Revision: 2056048
- new version 4.3.5
- disable test builds  due to missing source file in tests/

* Sat Apr 02 2022 umeabot <umeabot> 4.3.4-3.mga9
+ Revision: 1840874
- Mageia 9 Mass Rebuild

* Sat Feb 27 2021 neoclust <neoclust> 4.3.4-2.mga9
+ Revision: 1692468
- New version fixing security issues

* Tue Sep 15 2020 barjac <barjac> 4.3.3-2.mga8
+ Revision: 1626780
- fix lib path in .pc

* Fri Sep 11 2020 barjac <barjac> 4.3.3-1.mga8
+ Revision: 1624670
- new version 4.3.3
- fixes Mga#27256 - zeromq new security issue CVE-2020-15166
- patched to fix linking with pgm-5.3.128

* Sat May 23 2020 wally <wally> 4.3.2-3.mga8
+ Revision: 1586998
- drop python2 BR

* Sat Feb 15 2020 umeabot <umeabot> 4.3.2-2.mga8
+ Revision: 1528162
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Mon Aug 12 2019 barjac <barjac> 4.3.2-1.mga8
+ Revision: 1428886
- new version 4.3.1
- remove obsolete patch
- fix files list
- fixes Mga#25113 (security issue CVE-2019-13132)

* Thu Jan 17 2019 wally <wally> 4.3.1-2.mga7
+ Revision: 1357633
- disable static build (add patch to drop static targets from CMake files)
- drop unneeded libsodium fix

* Wed Jan 16 2019 barjac <barjac> 4.3.1-1.mga7
+ Revision: 1357492
- new version 4.3.1
- Remove patches fixed upstream
- Fix doc file paths and move all docs to -devel package
- Fix test failures with _cmake_skip_rpath %%nil (wally tnx)
- Use new %%ctest macro but not on BS
- Dont delete *.a as needed by cppzmq
- tidy files lists

* Sun Sep 23 2018 umeabot <umeabot> 4.2.3-3.mga7
+ Revision: 1302050
- Mageia 7 Mass Rebuild

* Thu Jan 11 2018 barjac <barjac> 4.2.3-2.mga7
+ Revision: 1192342
- re-diff dropped patch to add back libunwind support

* Thu Jan 11 2018 barjac <barjac> 4.2.3-1.mga7
+ Revision: 1192330
- new version 4.2.3
- re-diff patch0 and include fix for .pc path
- remove patch1
- use autosetup
- fix files list

* Mon Dec 18 2017 mokraemer <mokraemer> 4.2.2-3.mga7
+ Revision: 1183135
+ rebuild (emptylog)

* Wed Nov 15 2017 eatdirt <eatdirt> 4.2.2-2.mga7
+ Revision: 1177496
- Rebuild for new sodium

* Wed Feb 22 2017 wally <wally> 4.2.2-1.mga6
+ Revision: 1087318
- new version 4.2.2
- fix lib and devel pkg names
- switch to CMake builds
- split out cppzmq into its own src.rpm

* Mon Oct 10 2016 eatdirt <eatdirt> 4.1.4-3.mga6
+ Revision: 1060013
- Rebuild for new libsodium

* Sat Dec 26 2015 barjac <barjac> 4.1.4-2.mga6
+ Revision: 915182
- rebuild for sodium

* Fri Dec 18 2015 barjac <barjac> 4.1.4-1.mga6
+ Revision: 911780
- new version 4.1.4
- bug fix release

* Wed Dec 09 2015 barjac <barjac> 4.1.3-1.mga6
+ Revision: 909257
- new version 4.1.3

* Mon Nov 30 2015 neoclust <neoclust> 4.1.2-3.mga6
+ Revision: 907352
- Make check verbose

* Wed Aug 19 2015 barjac <barjac> 4.1.2-2.mga6
+ Revision: 865841
+ rebuild (emptylog)

* Thu Aug 13 2015 barjac <barjac> 4.1.2-1.mga6
+ Revision: 864350
- new version 4.1.2
- added BRs libsodium and openpgm
- new major 5

* Mon Aug 03 2015 barjac <barjac> 4.0.7-1.mga6
+ Revision: 860869
- new version fixes mga#16411
 ipyrhon died because of buggy zeromq version

* Fri May 08 2015 barjac <barjac> 4.0.6-0.1.mga5
+ Revision: 821476
- update to 4.0.6 to fix security bug Mga#15878

* Thu Nov 13 2014 barjac <barjac> 4.0.5-1.mga5
+ Revision: 796882
- new version 4.0.5 to fix following CVEs
- CVE-2014-7202 and CVE-2014-7203
- Mga#14525
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.0.4-2.mga5
+ Revision: 690870
- Mageia 5 Mass Rebuild

* Wed Jul 30 2014 barjac <barjac> 4.0.4-1.mga5
+ Revision: 658109
- new version 4.0.4
- includes zmq.hpp in devel from separate source zip
- added -utils sub-package for new binary file
- removes old obsolete on previous -utils package
- spec now caters for git snapshots

* Sat Oct 19 2013 umeabot <umeabot> 3.2.3-3.mga4
+ Revision: 527503
- Mageia 4 Mass Rebuild

* Sat Jun 08 2013 fwang <fwang> 3.2.3-2.mga4
+ Revision: 440416
- bump req
- lock libmajor

* Sun Jun 02 2013 kharec <kharec> 3.2.3-1.mga4
+ Revision: 434854
- new version 3.2.3

* Mon Jan 14 2013 umeabot <umeabot> 2.2.0-2.mga3
+ Revision: 387668
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Aug 13 2012 lebedov <lebedov> 2.2.0-1.mga3
+ Revision: 281133
- Update to 2.2.0.

* Mon Dec 19 2011 lebedov <lebedov> 2.1.11-1.mga2
+ Revision: 184113
- Update to 2.1.11.

* Mon Oct 03 2011 lebedov <lebedov> 2.1.10-1.mga2
+ Revision: 151318
- Update to 2.1.10.

* Tue Sep 06 2011 tv <tv> 2.1.9-1.mga2
+ Revision: 139458
- new release

* Sat Apr 30 2011 pterjan <pterjan> 2.1.6-1.mga1
+ Revision: 93609
- Update to 2.1.6 which is in mdv backports

* Mon Apr 18 2011 dams <dams> 2.1.4-4.mga1
+ Revision: 87825
- Add a 'Provides: ' to remove the old zeromq-utils (lib package)

* Fri Apr 15 2011 dams <dams> 2.1.4-3.mga1
+ Revision: 85568
+ rebuild (emptylog)

* Thu Apr 14 2011 dams <dams> 2.1.4-2.mga1
+ Revision: 85012
+ rebuild (emptylog)

* Thu Apr 14 2011 dams <dams> 2.1.4-1.mga1
+ Revision: 84840
- update to 2.1.4

* Mon Jan 31 2011 dmorgan <dmorgan> 2.0.10-1.mga1
+ Revision: 45309
- imported package zeromq


* Tue Nov 02 2010 Lev Givon <lev@mandriva.org> 2.0.10-1mdv2011.0
+ Revision: 592249
- import zeromq


